      subroutine brevior(in,jc,j,l1,l2,ncon,icon,imatr,atm1,atm2,
     +           shortcut,ringtype)
c
c  Routine to calculate shortcuts in rings for program ZEOTS
c
c  by:
c  German Sastre     Instituto de Tecnologia Quimica.
c  Julian D. Gale    Imperial College.
c
c  Passed arguments :
c
c  integer in                   : current T-atom
c  integer jc                   : coordination shell
c  integer j                    : index related to O(k1)-T-O(k2) current pair
c  integer l1, l2               : numbering of coincident atm1, atm2
c
c  Local variables :
c
c  integer connect              : atoms connected to side-1
c  integer newao1,connewao1,etc : candidate atom coordinated from side-1
c  integer rept                 : decide whether to store candidate
c  integer scsize, size2        : sizes of rings defined by shortcut
c  integer shortcut             : shortcut found if size smaller than ring
c
c ------------------------------------------------------------------------------

      implicit     none

      integer      maxatoms, nshellmax, nTmax, maxnb2
      parameter    ( maxatoms = 600 )
      parameter    ( nshellmax = 14 )
      parameter    ( maxnb2 = 1000 )
      parameter    ( nTmax = maxatoms/3 )

c passed variables
      integer      in, jc, j, l1, l2, ringtype

c common variables
      integer      ncon(nshellmax,nTmax), icon(maxnb2,nshellmax,nTmax)
      integer      imatr(3,maxnb2,nshellmax,nTmax)
      integer      atm1(maxnb2,nshellmax,5)
      integer      atm2(maxnb2,nshellmax,5)

c local variables
      integer      connect(2400,4)
      integer      i,m1,m2,m3,m4,m5,h,h1,h2,hh1
      integer      newao1, newao2, newao3, newao4
      integer      connewao1, connewao2, connewao3, connewao4
      integer      nn, oldnn, nextoldnn
      integer      jc1, rept, scsize, size2, shortcut, MR

c type of ring (0=even, 1=odd)
      if (ringtype.eq.0) then
        jc1=jc
        MR=2*jc-2
      else
        jc1=jc-1
        MR=2*jc-3
      endif

c search shortcut (which invalidate ring) from side-1 to side-2
      hh1=l1
      do m1=jc1,2,-1
        oldnn=0
        nn=1
        nextoldnn=nn
        connect(nn,1)=atm1(hh1,m1,1)
        connect(nn,2)=atm1(hh1,m1,2)
        connect(nn,3)=atm1(hh1,m1,3)
        connect(nn,4)=atm1(hh1,m1,4)
        do m3=2,2*jc-4
         do m5=oldnn+1,nextoldnn
          newao1=connect(m5,1)
          newao2=connect(m5,2)
          newao3=connect(m5,3)
          newao4=connect(m5,4)
          do m4=1,ncon(2,newao1)
            rept=0
            connewao1=icon(m4,2,newao1)
            connewao2=imatr(1,m4,2,newao1)+newao2
            connewao3=imatr(2,m4,2,newao1)+newao3
            connewao4=imatr(3,m4,2,newao1)+newao4
c do not include repeated
            do h=1,nn
              if ( (connewao1.eq.connect(h,1)).and.
     +             (connewao2.eq.connect(h,2)).and.
     +             (connewao3.eq.connect(h,3)).and.
     +             (connewao4.eq.connect(h,4)) ) rept=1
            enddo
            if ( (connewao1.eq.in).and.
     +           (connewao2.eq.0).and.
     +           (connewao3.eq.0).and.
     +           (connewao4.eq.0) ) rept=1
            h1=l1
            do h=jc1,2,-1
              if ((connewao1.eq.atm1(h1,h,1)).and.
     +            (connewao2.eq.atm1(h1,h,2)).and.
     +            (connewao3.eq.atm1(h1,h,3)).and.
     +            (connewao4.eq.atm1(h1,h,4))) then
c it belongs to side-1
                  rept=1
               endif
              h1=atm1(h1,h,5)
            enddo
            if (rept.eq.0) then
              h2=atm2(l2,jc1,5)
              do m2=jc1-1,2,-1
                if ((connewao1.eq.atm2(h2,m2,1)).and.
     +              (connewao2.eq.atm2(h2,m2,2)).and.
     +              (connewao3.eq.atm2(h2,m2,3)).and.
     +              (connewao4.eq.atm2(h2,m2,4))) then
c it belongs to side-2: ring finished
                  rept=1
                  scsize=m1+m2+m3-3
                  size2=jc-m1+jc1-m2+m3-1
                  if ((scsize.lt.MR).and.(size2.lt.MR)) shortcut=1
                  if (shortcut.eq.1) return
                endif
                h2=atm2(h2,m2,5)
              enddo
            endif
            if (rept.eq.0) then
              nn=nn+1
              connect(nn,1)=icon(m4,2,newao1)
              connect(nn,2)=connewao2
              connect(nn,3)=connewao3
              connect(nn,4)=connewao4
            endif
          enddo
         enddo
         oldnn=nextoldnn
         nextoldnn=nn
        enddo
        hh1=atm1(hh1,m1,5)
      enddo

      return
      end
