      subroutine shellgen(in,jc,icon,imatr,ncon,nats,atm)
c
c  Routine to generate shell 'jc' coming from k1,k2 for program ZEOTS
c
c  by:
c  German Sastre     Instituto de Tecnologia Quimica.
c  Julian D. Gale    Imperial College.
c
c  Passed arguments :
c
c  integer in                : current T-atom
c  integer jc                : coordination shell
c  integer atm1, atm2 (atm)  : atoms coordinated to k1 or k2
c  
c
c  Local variables :
c
c  integer psnewatm          : candidate to 'atm' ('ps' from 'pseudo')
c  integer nats              : number of 'atm' in each shell
c
c ------------------------------------------------------------------------------

      implicit     none

      integer      maxatoms, nshellmax, nTmax, maxnb2
      parameter    ( maxatoms = 600 )
      parameter    ( nshellmax = 14 )
      parameter    ( maxnb2 = 1000 )
      parameter    ( nTmax = maxatoms/3 )

c passed variables
      integer      in, jc, j

c common variables
      integer      icon(maxnb2,nshellmax,nTmax)
      integer      ncon(nshellmax,nTmax)
      integer      imatr(3,maxnb2,nshellmax,nTmax)
      integer      atm(maxnb2,nshellmax,5), nats(maxnb2)
      integer      psnewatm(maxnb2,nshellmax,5)


c local variables
      integer      l, psl, n, m, mm, skip

c generate shell 'jc' coming from k1 or k2
      l=0
      psl=0
      do n=1,nats(jc-1)
      do m=1,ncon(2,atm(n,jc-1,1))
        psl=psl+1
        psnewatm(psl,jc,1)=icon(m,2,atm(n,jc-1,1))
        psnewatm(psl,jc,2)=atm(n,jc-1,2)+imatr(1,m,2,atm(n,jc-1,1))
        psnewatm(psl,jc,3)=atm(n,jc-1,3)+imatr(2,m,2,atm(n,jc-1,1))
        psnewatm(psl,jc,4)=atm(n,jc-1,4)+imatr(3,m,2,atm(n,jc-1,1))
c 5 contains the number of the former atom in shell 'jc-1'
        psnewatm(psl,jc,5)=n
        skip=0
c accept atom (skip=1) if it belongs to shell 'jc'
        do mm=1,ncon(jc,in)
         if ( (psnewatm(psl,jc,1).eq.icon(mm,jc,in)).and.
     +        (psnewatm(psl,jc,2).eq.imatr(1,mm,jc,in)).and.
     +        (psnewatm(psl,jc,3).eq.imatr(2,mm,jc,in)).and.
     +        (psnewatm(psl,jc,4).eq.imatr(3,mm,jc,in)) ) skip=1
        enddo
        if (skip.eq.1) then
          l=l+1
          atm(l,jc,1)=psnewatm(psl,jc,1)
          atm(l,jc,2)=psnewatm(psl,jc,2)
          atm(l,jc,3)=psnewatm(psl,jc,3)
          atm(l,jc,4)=psnewatm(psl,jc,4)
          atm(l,jc,5)=psnewatm(psl,jc,5)
        endif
      enddo
      enddo
      nats(jc)=l

      return
      end
